# IRON-BARK: Inter Process Communication

Lightweight ROS like library, enabling communication between several programs via SharedMemory or socket.

### Features
* Module can be defined by a JSON file
* Module can communicate through:
  * SharedMemory (local)
  * socket (remote)

### In progress
* Overloading dict methods to call Sender and Listener

### Documentation
Documentation and example are provided [here](https://github.com/Zentetsu/IRONBark/wiki)

### More
[![PyPI version](https://badge.fury.io/py/IRONbark.svg)](https://badge.fury.io/py/IRONbark)
[![Python package](https://github.com/Zentetsu/IRONbark/actions/workflows/python-package.yml/badge.svg?branch=master)](https://github.com/Zentetsu/IRONbark/actions/workflows/python-package.yml)
![Upload Python Package](https://github.com/Zentetsu/IRONbark/workflows/Upload%20Python%20Package/badge.svg)
[![Python](https://shields.io/badge/python-3.10-blue.svg)](https://www.python.org/downloads/release/python-380/)
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
